{% load i18n %}
{% load navactive %}

<li class="nav-item">
    <a class="nav-link" href="{% url 'killstats:corporation_admin' %}">Corporation Overview</a>
</li>

<li class="nav-item">
    <a class="nav-link" href="{% url 'killstats:alliance_admin' %}">Alliance Overview</a>
</li>
{% if perms.killstats.admin_access %}
<li class="nav-item">
    <span class="nav-link">|</span>
</li>
<li class="nav-item">
    <a class="nav-link" href="{% url 'killstats:add_corp' %}">Add Corporation</a>
</li>
<li class="nav-item">
    <a class="nav-link" href="{% url 'killstats:add_alliance' %}">Add Alliance</a>
</li>
{% endif %}
