
/* Line System */
.li-circle{
	list-style-type: circle;
	margin-left: 25px;
}

/* Line System */
.li-none{
	margin-left: 25px;
}

/* CSS-Regeln für den Text links von der Linie */
.line-container {
	position: relative;
	width: 100%;
	text-align: left;
}

.line-text {
	position: absolute;
	left: 0;
	right: 0;
	top: -30px;
	z-index: 2;
}

.custom-line {
    height: 3px;
    border: none;
    background: linear-gradient(to right, rgb(0 170 255) 0%, transparent 80%, transparent 100%);
    z-index: 1;
}

.white {
    background: linear-gradient(to right, rgb(171 171 171) 0%, transparent 80%, transparent 100%);
}

#container {
    overflow: hidden;
}

fieldset.howto {
    overflow: hidden;
    margin-top: 20px;
}

#fieldcontents {
    float: left;
    width: calc(100% - 240px);
}

#fieldcontents img {
    max-width: 100%;
}

/* Style the Image Used to Trigger the Modal */
.zoom {
    opacity: 0.7;
    border-radius: 10px;
    cursor: pointer;
    transition: 0.3s;
}

.zoom:hover {
	opacity: 1;
	transform: scale(1.1);
}


/* Custom CSS for tab mouseover */
.nav-tabs .nav-link:hover {
    opacity: 0.8;
    color: rgb(255 255 255); /* Updated to modern color-function notation */
    border-color: rgb(255 255 255); /* Updated to modern color-function notation */
}
