KillstatsMonth = [
    {
        "kills": [],
        "losses": [
            {
                "title": "None",
                "killmail_id": 119303113,
                "name": "Gneuten",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/types/17634/icon?size=64",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 17634,
                "ship_name": "Caracal Navy Issue",
                "hash": "95ff494261eed2c4a790aad70c7f0053c75f89c6",
                "totalValue": 76734851,
                "date": "2024-07-07T21:38:59Z",
                "count": 0,
            },
            {
                "title": "None",
                "killmail_id": 119303075,
                "name": "Garthd",
                "character_id": 1004,
                "character_name": "Garthd",
                "portrait": "https://images.evetech.net/types/29340/icon?size=64",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c6667167aa7d65245a49d19d44275",
                "totalValue": 1000,
                "date": "2024-07-07T21:38:58Z",
                "count": 0,
            },
            {
                "title": "None",
                "killmail_id": 119303073,
                "name": "rotze Rotineque",
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "portrait": "https://images.evetech.net/types/29340/icon?size=64",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c5467167aa7d65245a49d19d44275",
                "totalValue": 94395699,
                "date": "2024-07-07T21:36:58Z",
                "count": 0,
            },
        ],
        "totalKills": 0,
        "totalLoss": 171131550,
        "shame": [
            {
                "title": "None",
                "killmail_id": 119303073,
                "name": "rotze Rotineque",
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "portrait": "https://images.evetech.net/types/29340/icon?size=64",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c5467167aa7d65245a49d19d44275",
                "totalValue": 94395699,
                "date": "2024-07-07T21:36:58Z",
                "count": 0,
            },
            {
                "title": "None",
                "killmail_id": 119303113,
                "name": "Gneuten",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/types/17634/icon?size=64",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 17634,
                "ship_name": "Caracal Navy Issue",
                "hash": "95ff494261eed2c4a790aad70c7f0053c75f89c6",
                "totalValue": 76734851,
                "date": "2024-07-07T21:38:59Z",
                "count": 0,
            },
            {
                "title": "None",
                "killmail_id": 119303075,
                "name": "Garthd",
                "character_id": 1004,
                "character_name": "Garthd",
                "portrait": "https://images.evetech.net/types/29340/icon?size=64",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c6667167aa7d65245a49d19d44275",
                "totalValue": 1000,
                "date": "2024-07-07T21:38:58Z",
                "count": 0,
            },
        ],
        "fame": [],
        "stats": [
            {
                "title": "Top Loss:",
                "killmail_id": 119303073,
                "name": "rotze Rotineque",
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "portrait": "https://images.evetech.net/types/29340/icon?size=64",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c5467167aa7d65245a49d19d44275",
                "totalValue": 94395699,
                "date": "2024-07-07T21:36:58Z",
                "count": 0,
            },
            {
                "title": "Worst Ship:",
                "type": "count",
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "portrait": "https://images.evetech.net/types/29340/icon?size=256",
                "count": 2,
                "loss": True,
            },
            {
                "title": "Top Victim: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 1,
                "loss": True,
            },
            {
                "title": "Alltime Victim: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 1,
                "loss": True,
            },
            {
                "title": "Top Ship:",
                "type": "count",
                "ship": 17634,
                "ship_name": "Caracal Navy Issue",
                "portrait": "https://images.evetech.net/types/17634/icon?size=256",
                "count": 1,
                "loss": False,
            },
            {
                "title": "Top Killer: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 1,
                "loss": False,
            },
            {
                "title": "Alltime Killer: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 1,
                "loss": False,
            },
        ],
    }
]

KillstatsEmpty = [
    {
        "kills": [],
        "losses": [],
        "totalKills": 0,
        "totalLoss": 0,
        "shame": [],
        "fame": [],
        "stats": [],
    }
]

Killstats_Stats = [{"stats": []}]

Killstats_Stats_Entry = [
    {
        "stats": [
            {
                "killmail_id": 119303073,
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c5467167aa7d65245a49d19d44275",
                "totalValue": 94395699,
                "date": "2024-07-07T21:36:58Z",
                "title": "Top Loss:",
                "portrait": "https://images.evetech.net/types/29340/icon?size=256",
                "zkb_link": "https://zkillboard.com/character/1002/",
                "count": 0,
            },
            {
                "title": "Worst Ship:",
                "type": "count",
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "portrait": "https://images.evetech.net/types/29340/icon?size=256",
                "count": 2,
                "loss": True,
                "zkb_link": "https://zkillboard.com/character/29340/",
            },
            {
                "title": "Top Victim: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 1,
                "loss": True,
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
            {
                "title": "Alltime Victim: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 1,
                "loss": True,
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
            {
                "killmail_id": 119303075,
                "character_id": 1004,
                "character_name": "Garthd",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c6667167aa7d65245a49d19d44275",
                "totalValue": 1000,
                "date": "2024-07-07T21:38:58Z",
                "title": "Top Kill:",
                "portrait": "https://images.evetech.net/types/29340/icon?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
                "count": 0,
            },
            {
                "title": "Top Ship:",
                "type": "count",
                "ship": 17634,
                "ship_name": "Caracal Navy Issue",
                "portrait": "https://images.evetech.net/types/17634/icon?size=256",
                "count": 1,
                "loss": False,
                "zkb_link": "https://zkillboard.com/character/17634/",
            },
            {
                "title": "Top Killer: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 1,
                "loss": False,
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
            {
                "title": "Alltime Killer: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 1,
                "loss": False,
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
        ]
    }
]


Killstats_Halls_Entry = [
    {
        "shame": [
            {
                "killmail_id": 119303073,
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c5467167aa7d65245a49d19d44275",
                "totalValue": 94395699,
                "date": "2024-07-07T21:36:58Z",
                "title": "rotze Rotineque",
                "portrait": "https://images.evetech.net/characters/1002/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1002/",
                "count": 0,
            },
            {
                "killmail_id": 119303113,
                "character_id": 1001,
                "character_name": "Gneuten",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 17634,
                "ship_name": "Caracal Navy Issue",
                "hash": "95ff494261eed2c4a790aad70c7f0053c75f89c6",
                "totalValue": 76734851,
                "date": "2024-07-07T21:38:59Z",
                "title": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1001/",
                "count": 0,
            },
            {
                "killmail_id": 119303075,
                "character_id": 1004,
                "character_name": "Garthd",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c6667167aa7d65245a49d19d44275",
                "totalValue": 1000,
                "date": "2024-07-07T21:38:58Z",
                "title": "Garthd",
                "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
                "count": 0,
            },
        ],
        "fame": [
            {
                "killmail_id": 119303075,
                "character_id": 1001,
                "character_name": "Gneuten",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c6667167aa7d65245a49d19d44275",
                "totalValue": 1000,
                "date": "2024-07-07T21:38:58Z",
                "title": "Garthd",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
                "count": 0,
            },
            {
                "killmail_id": 119303075,
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "corporation_id": 2001,
                "alliance_id": 3001,
                "ship": 29340,
                "ship_name": "Osprey Navy Issue",
                "hash": "1185d04b1b6c6667167aa7d65245a49d19d44275",
                "totalValue": 1000,
                "date": "2024-07-07T21:38:58Z",
                "title": "Garthd",
                "portrait": "https://images.evetech.net/characters/1002/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
                "count": 0,
            },
        ],
    }
]

Killstats_Kills_Entry = {
    "draw": 1,
    "recordsTotal": 1,
    "recordsFiltered": 1,
    "data": [
        {
            "killmail_id": 119303075,
            "killmail_date": "2024-07-07T21:38:58Z",
            "victim": {"id": 1004, "name": "Garthd"},
            "victim_ship": {"id": 29340, "name": "Osprey Navy Issue"},
            "victim_corporation_id": 2001,
            "victim_alliance_id": 3001,
            "hash": "1185d04b1b6c6667167aa7d65245a49d19d44275",
            "victim_total_value": 1000,
            "victim_fitted_value": 2000,
            "victim_destroyed_value": 3000,
            "victim_dropped_value": 1000,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459258618.29333,
            "victim_position_y": -4921962525.529236,
            "victim_position_z": -8888733393.073042,
            "attackers": [
                {
                    "character_id": 1001,
                    "corporation_id": 2001,
                    "alliance_id": 3001,
                    "ship_type_id": 17634,
                    "damage_done": 8056,
                    "final_blow": False,
                },
                {
                    "character_id": 1002,
                    "corporation_id": 2001,
                    "alliance_id": 3001,
                    "ship_type_id": 29340,
                    "damage_done": 2788,
                    "final_blow": True,
                },
            ],
        }
    ],
    "totalvalue": [1000],
}
